@@ -92,33 +92,6 @@ def parse_grid_type(dataset):
     return mesh_type
 
 
-@njit
-def _spherical_to_cartesian_unit_(node, r=6371):
-    """Converts spherical (lat/lon) coordinates to cartesian (x,y,z).
-
-    Final output is cartesian coordinates on a sphere of unit radius
-
-    Parameters
-    ----------
-    node: a list consisting of lat and lon
-
-    Returns: numpy array
-        Cartesian coordinates of length 3
-    """
-    lon = node[0]
-    lat = node[1]
-    lat, lon = np.deg2rad(lat), np.deg2rad(lon)
-    x = r * np.cos(lat) * np.cos(lon)  # x coordinate
-    y = r * np.cos(lat) * np.sin(lon)  # y coordinate
-    z = r * np.sin(lat)  # z coordinate
-
-    coord = np.array([x, y, z])
-    # make it coord on a sphere with unit radius
-    unit_coord = coord / np.linalg.norm(coord)
-
-    return unit_coord
-
-
 # Calculate the area of all faces.
 @njit
 def calculate_face_area(x,
@@ -175,10 +148,20 @@ def calculate_face_area(x,
         node1 = np.array([x[0], y[0], z[0]], dtype=np.float64)
         node2 = np.array([x[j + 1], y[j + 1], z[j + 1]], dtype=np.float64)
         node3 = np.array([x[j + 2], y[j + 2], z[j + 2]], dtype=np.float64)
+
         if (coords_type == "spherical"):
-            node1 = _spherical_to_cartesian_unit_(node1)
-            node2 = _spherical_to_cartesian_unit_(node2)
-            node3 = _spherical_to_cartesian_unit_(node3)
+            node1 = np.array(
+                _convert_node_lonlat_rad_to_xyz(
+                    [np.deg2rad(x[0]), np.deg2rad(y[0])]))
+            node2 = np.array(
+                _convert_node_lonlat_rad_to_xyz(
+                    [np.deg2rad(x[j + 1]),
+                     np.deg2rad(y[j + 1])]))
+            node3 = np.array(
+                _convert_node_lonlat_rad_to_xyz(
+                    [np.deg2rad(x[j + 2]),
+                     np.deg2rad(y[j + 2])]))
+
         for p in range(len(dW)):
             if quadrature_rule == "gaussian":
                 for q in range(len(dW)):
